<?php
##############################################################################
# G5-Scripts.de PHP Newsletter Script
# Copyright 2004-2013 G5-Scripts.de webmaster@G5-Scripts.de
# Last Modified                04.01.2013
# G5-Scripts.de                http://www.G5-Scripts.de
# Version                      1.2.7
##############################################################################
# Lizenzbedingungen (gekürzte Fassung)
# Copyright 2004-2013 G5-Scripts.de  All Rights Reserved.
# 
# Mit dem Herunterladen bzw. Erwerb der hier angebotenen Software erkennen die Nutzer 
# ausdrücklich die Lizenzbestimmungen gelesen und diese anerkannt zu haben.
#
# Beim Einsatz der Software im rein privaten Bereich ohne kommerzielle oder gewerbliche Absicht, 
# ist die Software für die Nutzung kostenfrei. Für die kommerzielle Nutzung sowie 
# eine optionale Entfernung des Copyright Hinweises ist eine geeignete Lizenz zu erwerben.
#
# Diese Software darf im rein privaten Bereich frei benutzt werden, 
# solange alle Copyright bzw. Powered By Verweise auf G5-Scripts.de, 
# eingebaut innerhalb der Software, erhalten bleibt. Diese müssen für Benutzer sichtbar sein 
# und in unveränderter Form dargestellt werden.
#
# Die Original-Software unver&auml;ndert darf weitergegeben, jedoch nicht verkauft
# oder wiederverkauft werden.
# Die angepasste bzw. ver&auml;nderte Software und Teile dieser d&uuml;rfen nicht
# weitergegeben, verkauft oder wiederverkauft werden.
#
# Die vollständige Fassung der Lizenzbedingungen finden Sie unter:
# http://www.g5-scripts.de/scripte__newsletter_php__lizenzbedingungen.htm
#
# Dieser Code stellt eine Erweiterung für das Hauptprogramm „Newsletter PHP“ 
# von G5-Scripts.de bereit, es handelt sich hierbei um ein sogenanntes Zusatzmodul. 
# Dieser Code kann und darf nur im Zusammenhang mit dem 
# Hauptprogramm „Newsletter PHP“ genutzt werden.
#
##############################################################################

// LAST CHANGE:		10.09.2011
// VERSION:			1.1


class NSLVersionInfo
{
	private $filePath;
    private $doc;
	private $mainVersion;
	
	public $version;
	public $plugin;
	public $other;
	
	public function __construct($mainVersion)
    {
		global $script_pfad;
		$this->mainVersion = $this->VersionStrToInt($mainVersion);
		$this->filePath = $script_pfad."/protected/data/version.xml";
		
		$refresh = true;
		if(file_exists( $this->filePath )){
			//check time
			$fileCreateDate = filectime($this->filePath);
			
			date_default_timezone_set('Europe/Berlin');
			
			if(date("ydm", $fileCreateDate) > date("ydm", time()))
				@unlink($this->filePath);
			else
				$refresh=false;
		}
		if($refresh){
			$download ="http://www.g5-scripts.de/scripte/newsletter_php/version.xml";
			$buffer="";
			if ($fd = @fopen ($download, "r")){
				while(!feof($fd)) {
					$buffer .= fread($fd, 2048);
				}
			}
			@fclose($fd);
			if(strlen($buffer) > 0){
				store($this->filePath, $buffer);
			}
		}

        $this->doc = new DOMDocument('1.0', 'UTF-8');
        $this->doc->formatOutput = true; 
        $this->doc->appendChild($this->doc->createElement('doc'));
    }
    
    public function Load()
    {
		if(file_exists($this->filePath)){
			@$ret = $this->doc->load($this->filePath);
			if($ret){
                //ist XML
				
				$this->InitVersionInfos();
				$this->InitPluginInfos();
				$this->InitOtherInfos();
				
                return true;
            }
        }
        
        return false;
    }
    
	private function InitVersionInfos(){
		$node = $this->getValue("version");
		if($node != null){
			for($c = 0; $c < $node->length; $c++){
				$subnode = $node->item($c);
				
				$value = "";
				$date  = "";
				if($subnode->hasAttributes()){
					$value = $subnode->getAttribute("value");
					$date  = $subnode->getAttribute("date");
				}
				$version = $this->VersionStrToInt($value);
				
				if($version > $this->mainVersion){
					$text = $subnode->nodeValue;
					$this->version .= '<div class="versionInfo" version="'.$version.'"><h3>Version '.$value.' vom '.$date.'</h3>'.$text.'</div>';
				}
			}
		}	
	}
	private function InitPluginInfos(){
		$node = $this->getValue("plugin");
		if($node != null){
			for($c = 0; $c < $node->length; $c++){
				$subnode = $node->item($c);
				
				$name ="";
				$state = 0;
				if($subnode->hasAttributes()){
					$name = $subnode->getAttribute("name");
					$state = $subnode->getAttribute("state");
				}
				
				
				$text = $subnode->nodeValue;
				$this->plugin .= '<div class="plugin '.($state=='1'? 'red' : 'gray').'" name="'.$name.'">'.$text.'</div>';				
			}
		}	
	}
	private function InitOtherInfos(){
		$node = $this->getValue("other");
		if($node != null){
			for($c = 0; $c < $node->length; $c++){
				$subnode = $node->item($c);
				
				$text = $subnode->nodeValue;
				$text = trim($text);
				if(strlen($text)>0){
					$this->other .= '<div class="other">'.$text.'</div>';
				}
			}
		}	
	}
	
    private function getValue($tagName){
        $val = "";
        return $this->doc->getElementsByTagName($tagName);
    }

	private function VersionStrToInt($version){
		$arr = explode('.', $version);
		$val =0;
		for($c = 0; $c <  4; $c++){
			$elem = count($arr) > $c ? $arr[$c] : 0;
			$val = $val*10+(int)$elem;
		}
		return $val;
	}
}

?>